@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.8 (default, Feb 24 2021, 21:46:12)  [GCC 7.3.0]
+# Python 3.8.11 (default, Aug  3 2021, 15:09:35)  [GCC 7.5.0]
 #
 # Command line options:
 #   ('--disable-generatedssuper-lookup', '')
@@ -38,10 +38,7 @@ import re as re_
 import base64
 import datetime as datetime_
 import decimal as decimal_
-## try:
-##     from lxml import etree as etree_
-## except ModulenotfoundExp_ :
-##     from xml.etree import ElementTree as etree_
+## from lxml import etree as etree_
 
 
 Validate_simpletypes_ = True
@@ -104,7 +101,7 @@ else:
 # Additionally, the generatedsnamespaces module can contain a python
 # dictionary named GenerateDSNamespaceTypePrefixes that associates element
 # types with the namespace prefixes that are to be added to the
-# "xsi:type" attribute value.  See the exportAttributes method of
+# "xsi:type" attribute value.  See the _exportAttributes method of
 # any generated element type and the generation of "xsi:type" for an
 # example of the use of this table.
 # An example table:
@@ -972,47 +969,55 @@ def _cast(typ, value):
 # Data representation classes.
 #
 
+from .enum_import02 import Type02_1
 
-class EnumType02_1(str, Enum):
+class EnumType01_1(str, Enum):
     FLOAT='float'
     INT='int'
     NAME='Name'
     TOKEN='token'
 
 
-class Type02_1(GeneratedsSuper):
+class Type01_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
-        'userdescription': MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
+        'username': MemberSpec_('username', 'xs:string', 0, 0, {'name': 'username', 'type': 'xs:string'}, None),
+        'inner01': MemberSpec_('inner01', 'Type02_1', 0, 0, {'name': 'inner01', 'type': 'Type02_1'}, None),
     }
     subclass = None
     superclass = None
-    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
+    def __init__(self, username=None, inner01=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
-        self.userdescription = userdescription
+        self.username = username
+        self.inner01 = inner01
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, Type02_1)
+                CurrentSubclassModule_, Type01_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if Type02_1.subclass:
-            return Type02_1.subclass(*args_, **kwargs_)
+        if Type01_1.subclass:
+            return Type01_1.subclass(*args_, **kwargs_)
         else:
-            return Type02_1(*args_, **kwargs_)
+            return Type01_1(*args_, **kwargs_)
     factory = staticmethod(factory)
-    def get_userdescription(self):
-        return self.userdescription
-    def set_userdescription(self, userdescription):
-        self.userdescription = userdescription
-    def hasContent_(self):
+    def get_username(self):
+        return self.username
+    def set_username(self, username):
+        self.username = username
+    def get_inner01(self):
+        return self.inner01
+    def set_inner01(self, inner01):
+        self.inner01 = inner01
+    def _hasContent(self):
         if (
-            self.userdescription is not None
+            self.username is not None or
+            self.inner01 is not None
         ):
             return True
         else:
             return False
-# end class Type02_1
+# end class Type01_1
 
 
 GDSClassesMapping = {
@@ -1023,5 +1028,6 @@ RenameMappings_ = {
 
 }
 __all__ = [
+    "Type01_1",
     "Type02_1"
 ]
