@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.8 (default, Feb 24 2021, 21:46:12)  [GCC 7.3.0]
+# Python 3.8.11 (default, Aug  3 2021, 15:09:35)  [GCC 7.5.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -40,10 +40,7 @@ import re as re_
 import base64
 import datetime as datetime_
 import decimal as decimal_
-## try:
-##     from lxml import etree as etree_
-## except ModulenotfoundExp_ :
-##     from xml.etree import ElementTree as etree_
+## from lxml import etree as etree_
 
 
 Validate_simpletypes_ = True
@@ -106,7 +103,7 @@ else:
 # Additionally, the generatedsnamespaces module can contain a python
 # dictionary named GenerateDSNamespaceTypePrefixes that associates element
 # types with the namespace prefixes that are to be added to the
-# "xsi:type" attribute value.  See the exportAttributes method of
+# "xsi:type" attribute value.  See the _exportAttributes method of
 # any generated element type and the generation of "xsi:type" for an
 # example of the use of this table.
 # An example table:
@@ -1013,7 +1010,7 @@ class PackageType(GeneratedsSuper):
         self.Address.insert(index, value)
     def replace_Address_at(self, index, value):
         self.Address[index] = value
-    def hasContent_(self):
+    def _hasContent(self):
         if (
             self.Address
         ):
