@@ -1229,6 +1229,26 @@ class GenTest(unittest.TestCase):
         self.remove('{}2_out.xml'.format(t_))
         self.remove('{}2_warnings.txt'.format(t_))
 
+    def test_047_doc_strings(self):
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'doc_strings'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles(
+            '{}1_sup.py'.format(t_),
+            '{}2_sup.py'.format(t_),
+            ('sys.stdout.write',))
+        self.compareFiles('{}1_sub.py'.format(t_), '{}2_sub.py'.format(t_))
+        # cleanup generated files
+        self.remove('{}2_sup.py'.format(t_))
+        self.remove('{}2_sub.py'.format(t_))
+
     def compareFiles(self, left, right, ignore=None):
         left = os.path.join(TEST_DIR, left)
         right = os.path.join(TEST_DIR, right)
